# - Config file for Dbpfm
#
# Once done, this will define:
#   Dbpfm_FOUND - system has Dbpfm
#   Dbpfm_INCLUDE_DIRS - the Dbpfm include directory
#   Dbpfm_VIEWS_PLUGIN_PATH - Chunk Views plugin installation path
#
# You do not need to link to dbpfm. Instead add it as dependency using add_dependencies().
# Dbpfm will dynamically load installed plugins.
#
# Copyright (C) 2014-2015 Wouter Haffmans <wouter@simply-life.net>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

set(Dbpfm_VERSION "")


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was DbpfmConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# LibDbpf and its image decoders plugin are always required - especially for the Dbpfm utilities
find_package(LibDbpf REQUIRED)
find_package(LibDbpfImageChunkDecoder REQUIRED)
# Other Qt dependencies
find_package(Qt5Gui   REQUIRED)
find_package(Qt5Quick REQUIRED)
# TODO Remove if Qt5Widgets not available by dbpfm
find_package(Qt5Widgets REQUIRED)

# Our library dependencies (contains definitions for IMPORTED targets)
# Note: target check is to avoid missing file during first build in the tree (for e.g. plugins using
# this target)
if(NOT TARGET dbpfm)
  include("${CMAKE_CURRENT_LIST_DIR}/DbpfmTargets.cmake")
endif()

# Plugin path; not checked, as it may not exist (no plugins yet) - it will quite definitely not
# exist during a full build (without any install ever).
set(Dbpfm_VIEWS_PLUGIN_INSTALL_DIR "bin/views/")
set(Dbpfm_VIEWS_PLUGIN_PATH "${PACKAGE_PREFIX_DIR}/bin/views/")
set(Dbpfm_TYPEINFO_PLUGIN_INSTALL_DIR "bin/typeinfo/")
set(Dbpfm_TYPEINFO_PLUGIN_PATH "${PACKAGE_PREFIX_DIR}/bin/typeinfo/")

# File with CMake utils for Dbpfm
set_and_check(Dbpfm_CMAKE_UTILS "${CMAKE_CURRENT_LIST_DIR}/DbpfmUtils.cmake")
include(${Dbpfm_CMAKE_UTILS})

# Default module config header file, used by the ADD_LIBDBPF_HANDLER_PLUGIN macro
set_and_check(Dbpfm_VIEW_PLUGIN_DEFAULT_CONFIG_H_FILE "${CMAKE_CURRENT_LIST_DIR}/dbpfmviewplugin_config.h.in")

# Default module config file, used by the ADD_LIBDBPF_HANDLER_PLUGIN macro
set_and_check(Dbpfm_VIEW_PLUGIN_DEFAULT_PACKAGECONFIG_FILE "${CMAKE_CURRENT_LIST_DIR}/DbpfmViewPluginConfig.cmake.in")

# Default module config header file, used by the ADD_DBPFM_TYPEINFO_PLUGIN macro
set_and_check(Dbpfm_TYPEINFO_PLUGIN_DEFAULT_CONFIG_H_FILE "${CMAKE_CURRENT_LIST_DIR}/dbpfmtypeinfoplugin_config.h.in")

# Default module config file, used by the ADD_DBPFM_TYPEINFO_PLUGIN macro
set_and_check(Dbpfm_TYPEINFO_PLUGIN_DEFAULT_PACKAGECONFIG_FILE "${CMAKE_CURRENT_LIST_DIR}/DbpfmTypeInfoPluginConfig.cmake.in")

# These are IMPORTED targets created by DbpfmTargets.cmake
get_target_property(Dbpfm_INCLUDE_DIRS dbpfm INTERFACE_INCLUDE_DIRECTORIES)
