# - Config file for the LibDbpf package
#
# Once done, this will define:
#   LibDbpf_FOUND - system has LibDbpf
#   LibDbpf_INCLUDE_DIRS - the LibDbpf include directory
#   LibDbpf_LIBRARY - LibDbpf library
#   LibDbpf_PLUGIN_PATH - Plugin installation path
#   LibDbpf_CMAKE_UTILS - Path to the CMake utilities file (LibDbpfUtils.cmake)
#
# Copyright (C) 2014-2015 Wouter Haffmans <wouter@simply-life.net>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

set(LibDbpf_VERSION "1.0.0")


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was LibDbpfConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Import targets
# Note: target check is to avoid missing file during first build in the complete libDbpf core tree
# (for e.g. plugins using this target)
if (NOT TARGET dbpf)
  include("${CMAKE_CURRENT_LIST_DIR}/LibDbpfTargets.cmake")
endif (NOT TARGET dbpf)

# Find dependencies
find_package(Qt5Core REQUIRED)

# Plugin path; not checked, as it may not exist (no plugins yet) - it will quite definitely not
# exist during a full build (without any install ever).
set(LibDbpf_DECODER_PLUGIN_INSTALL_DIR "bin/decoders/")
set(LibDbpf_DECODER_PLUGIN_PATH "${PACKAGE_PREFIX_DIR}/bin/decoders/")

# File with CMake utils for LibDbpf
set_and_check(LibDbpf_CMAKE_UTILS "${CMAKE_CURRENT_LIST_DIR}/LibDbpfUtils.cmake")
include(${LibDbpf_CMAKE_UTILS})

# Default module config header file, used by the ADD_LIBDBPF_DECODER_PLUGIN macro
set_and_check(LibDbpf_DECODER_PLUGIN_DEFAULT_CONFIG_H_FILE "${CMAKE_CURRENT_LIST_DIR}/libdbpfdecoderplugin_config.h.in")

# Default module config file, used by the ADD_LIBDBPF_DECODER_PLUGIN macro
set_and_check(LibDbpf_DECODER_PLUGIN_DEFAULT_PACKAGECONFIG_FILE "${CMAKE_CURRENT_LIST_DIR}/LibDbpfDecoderPluginConfig.cmake.in")

# These are IMPORTED targets created by LibDbpfTargets.cmake
set(LibDbpf_LIBRARIES dbpf)
get_target_property(LibDbpf_INCLUDE_DIRS dbpf INTERFACE_INCLUDE_DIRECTORIES)
