/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2014 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_DIRCHUNKMODEL_H
#define DBPF_DIRCHUNKMODEL_H

#include <QtCore/QAbstractItemModel>

#include "../libdbpf_config.h"

namespace Dbpf {

class DirChunkDecoder;
class DirChunkEntry;

class LIBDBPF_EXPORT DirChunkModel : public QAbstractTableModel
{
    Q_OBJECT

    Q_ENUMS(DirChunkColumns);

public:
    DirChunkModel(DirChunkDecoder* parent);

    enum DirChunkColumns {
        TypeColumn     = Qt::UserRole + 1,
        GroupColumn    = Qt::UserRole + 2,
        InstanceColumn = Qt::UserRole + 3,
        SizeColumn     = Qt::UserRole + 4,
    };

    virtual QVariant data(const QModelIndex& index, int role) const;
    virtual int columnCount(const QModelIndex& parent) const;
    virtual int rowCount(const QModelIndex& parent) const;
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role) const;

    virtual QHash<int, QByteArray> roleNames() const;

private Q_SLOTS:
    void rowUpdated(int row, const DirChunkEntry& entry);

    void appendingRow(const DirChunkEntry& entry);
    void appendedRow(int row, const DirChunkEntry& entry);

    void removingRow(int row);
    void removedRow(int row);

    void aboutToClear();
    void cleared();


private:
    DirChunkDecoder* m_dirChunkDecoder;
};
}

#endif // DBPF_DIRCHUNKMODEL_H
