/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2014 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_PALTCHUNKDECODER_H
#define DBPF_PALTCHUNKDECODER_H

#include <Dbpf/ChunkDecoder>

#include <QtGui/QColor>
#include <QtCore/QList>
#include <QtCore/QVector>

#include "libdbpfsims1spritesdecoders_config.h"

namespace Dbpf {

class PaltChunkDecoderPrivate;

class SIMS1SPRITESDECODERS_EXPORT PaltChunkDecoder : public Dbpf::ChunkDecoder
{
    Q_OBJECT

    Q_PROPERTY(QList<QColor> colors READ colors WRITE setColors NOTIFY colorsChanged);
    Q_PROPERTY(QVector<QRgb> colorTable READ colorTable WRITE setColorTable NOTIFY colorsChanged);

public:
    static const quint32 typeId = 0x50414C54; // 'PALT'

    PaltChunkDecoder(const Dbpf::Chunk& chunk, Dbpf::Container* container);
    virtual ~PaltChunkDecoder();

    QList<QColor> colors() const;
    QVector<QRgb> colorTable() const;

    virtual QJsonValue toJson() const;

    virtual void reload();

public Q_SLOTS:
    void setColor(int index, const QColor& color);
    void setColors(const QList<QColor>& colors);
    void setColorTable(const QVector<QRgb>& colorTable);

Q_SIGNALS:
    void colorChanged(int index, const QColor& color);
    void colorsChanged(const QList<QColor>& colors);

private:
    Q_DECLARE_PRIVATE(PaltChunkDecoder)
    PaltChunkDecoderPrivate* const d_ptr;
};
}

#endif // DBPF_PALTCHUNKDECODER_H
