/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2014 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_RSMPCHUNKDECODER_H
#define DBPF_RSMPCHUNKDECODER_H

#include "../chunkdecoder.h"
#include "../containerenums.h"

namespace Dbpf {

class RsmpEntryData;

class LIBDBPF_EXPORT RsmpEntry {
public:
    RsmpEntry();
    RsmpEntry(quint32 type, quint32 instance, quint32 offset, quint16 flags, const QString& label);
    RsmpEntry(const Chunk& chunk);
    RsmpEntry(const RsmpEntry& other);
    ~RsmpEntry();

    RsmpEntry& operator=(const RsmpEntry& other);
    bool operator==(const RsmpEntry& other) const;
    bool operator!=(const RsmpEntry& other) const { return !operator==(other); }

    bool isNull() const;

    quint32 type() const;
    quint32 instance() const;
    quint32 offset() const;
    quint16 flags() const;
    QString label() const;

private:
    QSharedDataPointer<RsmpEntryData> d;
};

class RsmpChunkDecoderPrivate;

/**
 * An RSMP chunk decoder is used to read and write IFF indexes.
 *
 * Note that the Container class uses this decoder to manipulate the index. Modifying it outside that
 * context is of no use as the container will throw away the changes when saving it.
 */
class LIBDBPF_EXPORT RsmpChunkDecoder: public Dbpf::ChunkDecoder
{
    Q_OBJECT
public:
    RsmpChunkDecoder(const Chunk& chunk, Container* container);
    virtual ~RsmpChunkDecoder();

    /**
     * Get the container's version (Rsmp0 or Rsmp1).
     */
    ContainerEnums::IndexVersion rsmpVersion() const;

    /**
     * Get the entries, with the type as key (which is how they are typically encoded.
     */
    QMultiMap<quint32, RsmpEntry> entries() const;

    /**
     * Remove all entries from the RSMP index.
     */
    void clear();

    /**
     * Register a new chunk in the RSMP index.
     */
    void addEntry(const Chunk& chunk);

    /**
     * Commit pending changes to the chunk.
     */
    void commit();

    virtual QJsonValue toJson() const;

public Q_SLOTS:
    virtual void reload();

private:
    class RsmpChunkDecoderPrivate* const d_ptr;
    Q_DECLARE_PRIVATE(RsmpChunkDecoder)
};
}

Q_DECLARE_TYPEINFO(Dbpf::RsmpEntry, Q_MOVABLE_TYPE);

#endif // DBPF_RSMPCHUNKDECODER_H
