/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2015 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_SIMS1LANGUAGES_H
#define DBPF_SIMS1LANGUAGES_H

#include <QtCore/QObject>
#include <QtCore/QLocale>

#include "libdbpfsims1stringdecoders_config.h"

namespace Dbpf
{

/**
 * QObject-derived Sims1Languages class, to make the enums accessible through the meta system
 * (especially QML).
 */
class SIMS1STRINGDECODERS_EXPORT Sims1Languages: public QObject
{
    Q_OBJECT

    Q_ENUMS(Sims1Language);

public:
    /**
     * An enum with all (known) Sims 1 languages.
     */
    enum Sims1Language {
        DefaultLanguage    =  0,
        USEnglish          =  1,
        UKEnglish          =  2,
        French             =  3,
        German             =  4,
        Italian            =  5,
        Spanish            =  6,
        Dutch              =  7,
        Danish             =  8,
        Swedish            =  9,
        Norwegian          = 10,
        Finnish            = 11,
        Hebrew             = 12,
        Russian            = 13,
        Portuguese         = 14,
        Japanese           = 15,
        Polish             = 16,
        SimplifiedChinese  = 17,
        TraditionalChinese = 18,
        Thai               = 19,
        Korean             = 20,
    };

    static QLocale       languageToLocale(Sims1Language language);
    static Sims1Language localeToLanguage(const QLocale& locale);
};

typedef Sims1Languages::Sims1Language Sims1Language;

} // namespace Dbpf

Q_DECLARE_METATYPE(Dbpf::Sims1Language);

#endif
