/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2015 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_SIMS1STRING_H
#define DBPF_SIMS1STRING_H

#include <QtCore/QLocale>
#include <QtCore/QSharedData>

#include "sims1languages.h"
#include "libdbpfsims1stringdecoders_config.h"

namespace Dbpf
{

class Sims1StringData;

/**
 * A Sims 1 String and its possible data.
 */
class SIMS1STRINGDECODERS_EXPORT Sims1String
{
public:
    Sims1String(const QString& string = QString(), const QString& comment = QString(), Sims1Language language = Sims1Languages::DefaultLanguage);

    Sims1String(const Sims1String& other);
    Sims1String& operator=(const Sims1String& other);

    ~Sims1String();

    /**
     * Get the string value.
     */
    QString string() const;

    void setString(const QString& value);

    /**
     * Get the string's comment.
     */
    QString comment() const;

    void setComment(const QString& value);

    /**
     * Get the string's language.
     */
    Sims1Language language() const;

    void setLanguage(Sims1Language value);

private:
    QSharedDataPointer<Sims1StringData> d;
};

}

Q_DECLARE_TYPEINFO(Dbpf::Sims1String, Q_MOVABLE_TYPE);


#endif // DBPF_SIMS1STRING_H
