/*
 * <one line to give the program's name and a brief idea of what it does.>
 * Copyright (C) 2015  W. Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_SIMS4CWALCHUNKDECODER_H
#define DBPF_SIMS4CWALCHUNKDECODER_H

#include <Dbpf/ChunkDecoder>
#include <QtGui/QColor>

#include "stblchunkdecoder.h"
#include "libdbpfsims4walldecoders_config.h"

namespace Dbpf {

class Sims4CwalChunkDecoderPrivate;

class SIMS4WALLDECODERS_EXPORT Sims4CwalChunkDecoder : public Dbpf::ChunkDecoder
{
    Q_OBJECT

    Q_PROPERTY(quint32 version READ version);
    Q_PROPERTY(quint32 catalogVersion READ catalogVersion);
    Q_PROPERTY(quint32 nameId READ nameId);
    Q_PROPERTY(QString name READ name);
    Q_PROPERTY(quint32 descriptionId READ descriptionId);
    Q_PROPERTY(QString description READ description);
    Q_PROPERTY(quint32 price READ price);
    Q_PROPERTY(QList<Dbpf::ChunkId> styles READ styles);
    Q_PROPERTY(QList<quint16> tags READ tags);
    Q_PROPERTY(QList<Dbpf::Sims4CwalChunkDecoder::SellingPoint> sellingPoints READ sellingPoints);

    Q_PROPERTY(QList<Dbpf::Sims4CwalChunkDecoder::MaterialDefinition> materialDefinitions READ materialDefinitions);
    Q_PROPERTY(QList<Dbpf::Sims4CwalChunkDecoder::ImageGroup> imageGroups READ imageGroups);
    Q_PROPERTY(QList<QRgb> colors READ colors);

    Q_PROPERTY(quint64 catalogGroupId READ catalogGroupId);

public:
    static const quint32 cwalTypeId = 0xd5f0f921;
    static const quint32 thumbnailTypeId = 0x3C2A8647; // JPEG thumbnails

    struct SellingPoint
    {
        quint16 commodity;
        quint32 amount;
    };

    struct MaterialDefinition
    {
        quint8 label;
        ChunkId chunkId;
    };

    struct ImageGroup
    {
        quint8 label;
        ChunkId chunkIds[3];
    };

    Sims4CwalChunkDecoder(const Dbpf::Chunk& chunk, Dbpf::Container* container);
    virtual ~Sims4CwalChunkDecoder();

    virtual void reload();
    void commit();
    virtual QJsonValue toJson() const;

    // Property getters
    quint32 version() const;
    quint32 catalogVersion() const;
    quint32 nameId() const;
    QString name(StblChunkDecoder::Sims4Language language = StblChunkDecoder::English) const;
    quint32 descriptionId() const;
    QString description(StblChunkDecoder::Sims4Language language = StblChunkDecoder::English) const;
    quint32 price() const;
    QList<Dbpf::ChunkId> styles() const;
    QList<quint16> tags() const;
    QList<Dbpf::Sims4CwalChunkDecoder::SellingPoint> sellingPoints() const;

    QList<Dbpf::Sims4CwalChunkDecoder::MaterialDefinition> materialDefinitions() const;
    QList<Dbpf::Sims4CwalChunkDecoder::ImageGroup> imageGroups() const;
    QList<QRgb> colors() const;

    quint64 catalogGroupId() const;


private:
    class Sims4CwalChunkDecoderPrivate* const d_ptr;
    Q_DECLARE_PRIVATE(Sims4CwalChunkDecoder)
};
}

#endif // DBPF_SIMS4CWALCHUNKDECODER_H
