/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2014 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_SPR1CHUNKDECODER_H
#define DBPF_SPR1CHUNKDECODER_H

#include <Dbpf/ChunkDecoders/MultiImageChunkDecoder>

#include "libdbpfsims1spritesdecoders_config.h"

namespace Dbpf {

class PaltChunkDecoder;
class Spr1ChunkDecoderPrivate;

/**
 * Decoder for SPR# chunks.
 */
class SIMS1SPRITESDECODERS_EXPORT Spr1ChunkDecoder : public Dbpf::MultiImageChunkDecoder
{
    Q_OBJECT
    /** SPR# version (always 502, 503, 504, 504 or 1001) */
    Q_PROPERTY(quint32 version READ version NOTIFY versionChanged)
    /** Amount of frames in chunk */
    Q_PROPERTY(quint32 frameCount READ frameCount NOTIFY frameCountChanged)
    /** The palette's id for frames */
    Q_PROPERTY(quint32 paletteId READ paletteId NOTIFY paletteChanged)
    /** The palette decoder. */
    Q_PROPERTY(Dbpf::PaltChunkDecoder* palette READ palette NOTIFY paletteChanged)
    /** Frame offsets */
    Q_PROPERTY(QList<quint32> offsets READ offsets NOTIFY offsetsChanged)

public:
    static const quint32 typeId = 0x53505223; // 'SPR#'

    Spr1ChunkDecoder(const Dbpf::Chunk& chunk, Dbpf::Container* container);
    virtual ~Spr1ChunkDecoder();

    virtual void reload();

    quint32 version() const;
    quint32 frameCount() const;
    quint32 paletteId() const;
    PaltChunkDecoder* palette() const;

    QList<quint32> offsets() const;

    virtual QJsonValue toJson() const;

Q_SIGNALS:
    void versionChanged(quint32 version);
    void paletteChanged();
    void frameCountChanged(quint32 frameCount);
    void offsetsChanged(const QList<quint32>& offsets);

private:
    QImage readFrame(QIODevice* buffer);

    PaltChunkDecoder* paltDecoder(quint32 paletteId) const;

    Q_DECLARE_PRIVATE(Spr1ChunkDecoder);
    Spr1ChunkDecoderPrivate* d_ptr;
};
}

#endif // DBPF_SPR1CHUNKDECODER_H
