/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2014 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_STBLHELPER_H
#define DBPF_STBLHELPER_H

#include <QtCore/QObject>

#include "stblchunkdecoder.h"
#include "libdbpfsims4walldecoders_config.h"

namespace Dbpf {

class Container;
class StblChunkDecoder;

class StblHelperPrivate;

class SIMS4WALLDECODERS_EXPORT StblHelper : public QObject
{
    Q_OBJECT

    Q_PROPERTY(Dbpf::Container* container READ container WRITE setContainer NOTIFY containerChanged)

public:
    explicit StblHelper(Dbpf::Container* container);
    virtual ~StblHelper();

    Dbpf::Container* container() const;

    StblChunkDecoder* locateString(quint32 key, StblChunkDecoder::Sims4Language locale) const;

    QString string(quint32 key, StblChunkDecoder::Sims4Language locale, const QString& defaultValue = QString()) const
    {
        StblChunkDecoder* decoder = locateString(key, locale);
        if (!decoder) {
            return defaultValue;
        }

        return decoder->string(key);
    }

public Q_SLOTS:
    void setContainer(Dbpf::Container* container);

Q_SIGNALS:
    void containerChanged(Dbpf::Container* container);

private:
    Q_DECLARE_PRIVATE(StblHelper);
    StblHelperPrivate* d_ptr;
};
}

#endif // DBPF_STBLHELPER_H
