/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2015 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_STRCHUNKDECODER_H
#define DBPF_STRCHUNKDECODER_H

#include <Dbpf/ChunkDecoders/TableChunkDecoder>

#include "sims1string.h"
#include "libdbpfsims1stringdecoders_config.h"

namespace Dbpf
{

class StrChunkDecoderPrivate;

/**
 * STR#/CTSS/etc chunk reader. For Sims 1 strings.
 */
class SIMS1STRINGDECODERS_EXPORT StrChunkDecoder : public Dbpf::TableChunkDecoder
{
    Q_OBJECT

    Q_PROPERTY(QList<Dbpf::Sims1String> strings READ strings NOTIFY stringsChanged);
    Q_PROPERTY(QStringList stringList READ stringList NOTIFY stringsChanged);

public:
    static const quint32 ctssTypeId = 0x43545353; // 'CTSS'
    static const quint32 famsTypeId = 0x46414D73; // 'FAMs'
    static const quint32 ttasTypeId = 0x54544173; // 'TTAs'
    static const quint32 strTypeId  = 0x53545223; // 'STR#'

    StrChunkDecoder(const Dbpf::Chunk& chunk, Dbpf::Container* container);
    virtual ~StrChunkDecoder();

    virtual void reload();

    QList< Dbpf::Sims1String > strings() const;
    QStringList stringList() const;

    virtual QJsonValue toJson() const;

Q_SIGNALS:
    void stringsChanged(const QStringList& strings);

private:
    Q_DECLARE_PRIVATE(StrChunkDecoder);
    StrChunkDecoderPrivate* d_ptr;
};

} // namespace Dbpf

#endif // DBPF_STRCHUNKDECODER_H
