/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2014 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_CONTAINERMODEL_H
#define DBPF_CONTAINERMODEL_H

#include <QtCore/QAbstractItemModel>

#include "libdbpf_config.h"

namespace Dbpf {

class Container;
class Chunk;

class LIBDBPF_EXPORT ContainerModel : public QAbstractItemModel
{
    Q_OBJECT

    Q_PROPERTY(Dbpf::Container* container READ container WRITE setContainer);

public:
    enum ContainerModelRoles {
        TypeRole = Qt::UserRole + 1,
        GroupRole,
        InstanceRole,
        InstanceHiRole,
        InstanceLoRole,
        NameRole,
        OffsetRole,
        FilesizeRole
    };

    explicit ContainerModel(Container* container = 0, QObject* parent = 0);
    virtual ~ContainerModel();

    virtual QVariant data(const QModelIndex& index, int role) const;
    virtual int columnCount(const QModelIndex& parent) const;
    virtual int rowCount(const QModelIndex& parent) const;
    virtual QModelIndex parent(const QModelIndex& child) const;
    virtual QModelIndex index(int row, int column, const QModelIndex& parent) const;
    virtual bool hasChildren(const QModelIndex& parent) const;

    Container* container() const
    {
        return m_container;
    }

    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

    virtual QHash< int, QByteArray > roleNames() const;

    virtual void sort(int column, Qt::SortOrder order = Qt::AscendingOrder)
    {
        layoutAboutToBeChanged();
        layoutChanged();
    }

    Q_INVOKABLE virtual QVariantMap get(int row) const;

public Q_SLOTS:
    void setContainer(Container* container);

private Q_SLOTS:
    void chunkAdded(const Chunk& chunk, int index);
    void chunkAboutToBeRemoved(const Chunk& chunk, int index);
    void chunkRemoved(const Chunk& chunk, int index);
    void chunkUpdated(const Chunk& chunk, int index);

    void startFileLoad()
    {
        beginResetModel();
    }

    void endFileLoad()
    {
        endResetModel();
    }

private:
    QVariant indexAsRole(quint32 value, int role) const;
    QVariant indexAsRole(quint64 value, int role) const;
    QVariant sizeAsRole(quint32 size, int role) const;

private:
    Container* m_container;
};
}

Q_DECLARE_METATYPE(Dbpf::ContainerModel*);

#endif // DBPF_CONTAINERMODEL_H
