/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2014 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_FALLBACKCHUNKDECODER_H
#define DBPF_FALLBACKCHUNKDECODER_H

#include "chunkdecoder.h"
#include "libdbpf_config.h"

namespace Dbpf {

/**
 * The Fallback Chunk Decoder can be used as a default decoder for chunks, to read the basic chunk
 * data. Essentially it acts as a QObject proxy of the chunk, which can be especially useful in
 * QML to get basic chunk data (where Chunk cannot be supported, because it doesn't inherit QObject).
 *
 * A UI can also specifically request this decoder type if this is all it needs; without having to
 * load a decoder that may perform expensive interpretation of the data. For this reason, do *not*
 * subclass the FallbackChunkDecoder. Instead create your decoder as subclass of ChunkDecoder
 * directly.
 */
class LIBDBPF_EXPORT FallbackChunkDecoder : public Dbpf::ChunkDecoder
{
    Q_OBJECT

public:
    FallbackChunkDecoder(const Dbpf::Chunk& chunk, Dbpf::Container* container);
    virtual ~FallbackChunkDecoder();

public Q_SLOTS:
    virtual void reload() {};

};
}

#endif // DBPF_FALLBACKCHUNKDECODER_H
