/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2014 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPF_FNVHASH_H
#define DBPF_FNVHASH_H

#include <QtCore/QString>
#include <QtCore/QByteArray>

#include "libdbpf_config.h"

namespace Dbpf {

template<class T, T prime, T offset>
class LIBDBPF_EXPORT FnvHash
{
public:
    explicit FnvHash(const QString& string)
    {
        m_value = computeHash(string.toLower().toUtf8());
    }

    explicit FnvHash(const QByteArray& data)
    {
        m_value = computeHash(data);
    }

    T value() const
    {
        return m_value;
    }

    operator T() const
    {
        return m_value;
    }

protected:
    T m_value;

private:
    T computeHash(const QByteArray& data)
    {
        T hash = offset;
        Q_FOREACH(char c, data) {
            hash *= prime;
            hash ^= c;
        }

        return hash;
    }
};

typedef FnvHash<quint64, 0x00000100000001B3,  0xCBF29CE484222325> FnvHash64;
typedef FnvHash<quint32, 0x01000193,  0x811C9DC5> FnvHash32;

class FnvHash24: public FnvHash32
{
public:
    explicit FnvHash24(const QString& string)
      : FnvHash32(string)
    {
        m_value = fixHash(m_value);
    }

    explicit FnvHash24(const QByteArray& data)
      : FnvHash32(data)
    {
        m_value = fixHash(m_value);
    }

private:
    quint32 fixHash(quint32 hash)
    {
        quint8  msb  = quint8(hash >> 24);
        return (hash & 0x00FFFFFF) ^ msb;
    }
};

}

#endif // DBPF_FNVHASH_H
