/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2014 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPFM_CWALCHUNKVIEW_H
#define DBPFM_CWALCHUNKVIEW_H

#include <Dbpf/Chunk>
#include <Dbpf/ChunkDecoder>
#include <Dbpf/ChunkDecoders/ImageFileChunkDecoder>

#include <Dbpfm/ChunkView>
#include <Dbpfm/DbpfmConfig>


namespace Dbpfm {

class CwalChunkViewPrivate;

class CwalChunkView: public Dbpfm::ChunkView
{
    Q_OBJECT

    // List of previews is as QObject* list, due to QML limitations on QList<QObjectDerived*> (which is not recognized as array)
    Q_PROPERTY(QList<QObject*> previews                     READ previews                                         NOTIFY previewsChanged)
    Q_PROPERTY(Dbpf::ImageFileChunkDecoder* currentPreview  READ currentPreview                                   NOTIFY currentPreviewChanged)
    Q_PROPERTY(int currentPreviewIndex                      READ currentPreviewIndex WRITE setCurrentPreviewIndex NOTIFY currentPreviewIndexChanged)
    Q_PROPERTY(QSize maxPreviewSize                         READ maxPreviewSize      STORED false                 NOTIFY maxPreviewSizeChanged)
    Q_PROPERTY(bool replaceAll                              READ willReplaceAll      WRITE setReplaceAll          NOTIFY replaceAllChanged)

public:
    explicit CwalChunkView(QQuickItem* parent = 0);
    virtual ~CwalChunkView();

    virtual QString title() const {
        return tr("Wall");
    }

    QList<QObject*> previews() const;
    Dbpf::ImageFileChunkDecoder* currentPreview() const;
    int currentPreviewIndex() const;
    QSize maxPreviewSize() const;
    bool willReplaceAll() const;

public Q_SLOTS:
    virtual void load(const Dbpf::Chunk& chunk, Dbpf::Container* container);

    void setCurrentPreviewIndex(int index);

    /**
     * Whether or not to replace all thumbnails by automatically scaling the image.
     */
    void setReplaceAll(bool replaceAll);

    Q_INVOKABLE void replaceThumbnail(const QUrl& fileUrl);

    Q_INVOKABLE void replaceThumbnail(const QString& filename);

Q_SIGNALS:
    void previewsChanged(const QList<Dbpf::ImageFileChunkDecoder*>& previews);
    void currentPreviewChanged(Dbpf::ImageFileChunkDecoder* preview);
    void currentPreviewIndexChanged(int index);
    void maxPreviewSizeChanged(const QSize& size);
    void replaceAllChanged(bool willReplaceAll);

    void error(const QString& message);

private:
    QQmlComponent* m_component;

    Q_DECLARE_PRIVATE(CwalChunkView);
    CwalChunkViewPrivate* d_ptr;
};
}

#endif // DBPFM_CWALCHUNKVIEW_H
