/*
 * LibDbpf - Library to access SimCity/Sims Database Pacakge Files
 * Copyright (C) 2014 Wouter Haffmans <wouter@simply-life.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef DBPFM_MULTIIMAGECHUNKVIEW_H
#define DBPFM_MULTIIMAGECHUNKVIEW_H

#include <Dbpfm/ChunkView>

#include "dbpfmimageviews_config.h"

namespace Dbpfm {
class MultiImageChunkViewPrivate;

class IMAGEVIEWS_EXPORT MultiImageChunkView
  : public Dbpfm::ChunkView
{
    Q_OBJECT

    Q_PROPERTY(int currentIndex READ currentIndex WRITE setCurrentIndex STORED false NOTIFY currentIndexChanged)
    Q_PROPERTY(int imageCount READ imageCount STORED false NOTIFY imageCountChanged)
    Q_PROPERTY(QSize maxImageSize READ maxImageSize NOTIFY maxImageSizeChanged)

public:
    explicit MultiImageChunkView(QQuickItem* parent = 0);
    virtual ~MultiImageChunkView();

    virtual QString title() const {
        return tr("Images");
    }

    virtual void load(const Dbpf::Chunk& chunk, Dbpf::Container* container);

    virtual void setChunkDecoder(Dbpf::ChunkDecoder* chunkDecoder);

    int currentIndex() const;
    int imageCount() const;
    QSize maxImageSize() const;

public Q_SLOTS:
    void setCurrentIndex(int index);

Q_SIGNALS:
    void currentIndexChanged(int currentIndex);
    void imageCountChanged(int imageCount);
    void maxImageSizeChanged(const QSize& maxImageSize);

private Q_SLOTS:
    void imagesChanged(const QList<QImage>& images);

private:
    Q_DECLARE_PRIVATE(MultiImageChunkView);
    MultiImageChunkViewPrivate* d_ptr;
};

}

#endif // DBPFM_MULTIIMAGECHUNKVIEW_H
